package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$"`0`````````````"`!(````!``$78````#0``,9D```!```T`"``
M"``H`!L`&@````8````T``$`-``!`#0```$````!``````4````$`````P``
M`30``0$T``$!-````!,````3````!`````$````!```````!`````0````"S
MD```LY`````%``$```````$``,````+````"P`````50```5D`````<``0``
M`````@``P!0``L`4``+`%````1@```$8````!@````0````$```!2``!`4@`
M`0%(````1````$0````$````!&1TY5```+`8``&P&``!L!@```#D````Y```
M``0````$9'3E40``````````````````````````````!@````0O;&EB+VQD
M+6QI;G5X+G-O+C(```````0````0`````4=.50```````````@````8````@
M````!````!0````#1TY5`*G6[&<9H#YW"'/2[2,WX'M8<]G!````0P````,`
M```0````"2+D`*+4`6>"2DIJ"#D!409/$AB"$`$C'P``0*000+(""`*``B#2
ME`!AFJ!.`L`@4#1%&$`)`F1@W267-*!&OR@``````````P````0````%````
M!@````D`````````#@````\````1````$P```!<````9```````````````:
M````'0```!X````?````(@```"0````F````*``````````J````*P```"P`
M```N````+P```#`````Q`````````````````````````#,````U````-@``
M`#<````Y`````````#H`````````.P```#X```!`````0@```$0```!&````
M`````$@`````````20```$L```!-````3@```$\```!1````4@```%0```!6
M`````````%@```!9````6@```%L`````&?8"HW&RU<G%A7-M8'9?7B+AT"JO
M90"CD.]:HAC$5^*?RJO>_ZY*SJC'(I^0!ZE3KPP_S,CO\D/I$)!\S;)L!<#C
M2ZP-.:T\PL/[Z`*0/^UPXV]V_X>D!Z3Y(P'V/4XN\5KJ%M;K52V0!8G%:TKP
M>V($K9(02V9"#8)T@6=HDJ`8?.B;#N_3ZE<UV8L-@G60P?#C-WR6\(8<DY9?
MO=:?&\+=F(M1$`(<#O&-N0*P="&+]BSMYYU(L2))269`G+G%?)U-0*@-_"F%
MI3(%')/>[6C4(IC):%I/:Z/=IW.Q#BT]X`[&@9SYAAR3NYU>`/?:$N^884C^
MWRQ\EGX_@OK08A4BZ]_Z:7IN4EJ25P\[FEKY40OO[-5%0Q]`.UB$,(1Q*'=2
MX$\@A=^$!%'3'T`YR2#.(_9\DN.[_"R?T7U+T+P<D]M7#8*X,%]]&U'_AX["
M').5N]Y.;S4=T]OS#^_2_?]](DH<6''9``````````````````````````P`
M`````````"`````````;```````````@```````"(P`"PE0`````$@``````
M`;X``L'$`````!(```````01``+"V``````2```````!,``"PO``````$@``
M````!&<``L-0`````!(```````#M``+$*``````2```````#&P`"PC``````
M$@``````!%,``L*$`````!(```````(\``+"S``````2```````#E``"PXP`
M````$@``````!'$``L2X`````!(```````%U``+"```````2```````#@P`"
MQ)0`````$@```````0P``L4P`````!(```````!/``+$T``````2```````#
MBP`"Q0P`````$@```````UT``5!8````!!$```X```*8``+#[``````2````
M````V``"Q%@`````$@```````DH``L3$`````!(```````0<``+"_``````2
M```````$/``"PZ0`````$@```````SP``L%P`````!(```````25``+">```
M```2```````$AP`"PN0`````$@```````@4``L1D`````!(```````2H``+%
M4`````0A```8```"<0`"PR``````$@```````R@``L*0`````!(```````/V
M``+$$``````2```````#S``"Q(@`````$@```````90``L'H`````!(`````
M``!D``+$Z``````2```````!40`!4$``````$@``#0```'D``L4D`````!(`
M``````/\``+#7``````2```````"8P`"P[``````$@```````:T``L+`````
M`!(```````2.``+$]``````2```````$?P`"Q$P`````$@```````/X``L)(
M`````!(```````"0``+%```````2````````7@`!%(@`````$@``"P``!"0`
M`L'T`````!(```````*,``+$<``````2```````!5P`"Q'P`````$@``````
M!"X``L,4`````!(```````2G``+%4`````01```8```#(P`"PIP`````$@``
M`````=\``L3<`````!(```````)5``+#U``````2```````#V@`"Q!P`````
M$@```````:@``L&@`````!(````````]``+$-``````2```````$J0`"Q5``
M```$(0``&````"\``L,(`````!(```````/$``+!W``````2````````H0`"
MPRP`````$@```````^$``L-T`````!(```````.=``+#O``````2```````#
M%``"Q*``````$@```````C,``L(\`````!(```````-^``+%&``````2````
M```"GP`"PJ@`````$@```````?$``L*T`````!(```````-L``+")``````2
M```````!L@`"P_@`````$@```````TT``L/(`````!(```````1#``+$0```
M```2```````$L0`"Q5``````$`#_\0```60``L,X`````!(```````$>``+$
MK``````2````````L@`"P7P`````$@```````4(``L.8`````!(```````*!
M``+!N``````2```````#I@`"Q`0`````$@```````[<``L.``````!(`````
M``3$``+5D``````0`/_Q```$3``"PV@`````$@```````,D``L-$`````!(`
M``````/O``+#X``````2```````#Z``"PF``````$@```````=$``L)L````
M`!(```````/3``+!B``````2```````$8``"PA@`````$@```````8<``L(,
M`````!(```````*J``+%6````!,1```8```#O@`"P90`````$@``````!`,`
M`L&L`````!(```````2X``+%4``````0`/_Q`&QI8G!E<FPN<V\`7U]G;6]N
M7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E
M<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%]I;FET`%!E<FQ?265X
M:71?9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M
M<&-V7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P
M='(`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])
M<&%R<V5R7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E
M<FQ?271O<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T
M<'9N`%]F:6YI`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?
M26EN7V5V86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R
M`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R
M;%]S=E]S971P=@!097)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?
M<'1R`%!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T
M8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A
M<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W
M<F%P`&QI8G)E<V]L=BYS;RXR`&QI8FYS;"YS;RXQ`&QI8F1L+G-O+C(`;&EB
M;2YS;RXV`&QI8F-R>7!T+G-O+C$`;&EB=71I;"YS;RXQ`&QI8G!T:')E860N
M<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`
M7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S
M960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&=E
M='!W=6ED`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER
M`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S
M=')S='(`<FUD:7(`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN
M:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I
M;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA
M:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`"]U<W(O;&EB
M+W!E<FPU+T-/4D4`1TQ)0D-?,BXT`$=,24)#7S(N,P!'3$E"0U\R+C,N,@!'
M3$E"0U\R+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP``````````````````4`
M```%````!P`$`````P`)`````P```````P`!``,```````,``P`"``,``P``
M``,````"``,``P```````0````,````#``,``P```````0`%```````(``,`
M`@```````P```````P````,````#``,`!P````,```````8````"``,``0``
M````````````"0`#``$``P````,``P````,``P```````P`$``$``0`&```#
M4P```!````!P#6EI%`````D```3=````$`UI:1,````(```$YP```!`):1ER
M````!@``!/$````0#6EI$@````4```3]````$`EI&70````$```%!P```!`-
M:6D0`````P``!1,```````$``@```P0````0``````UI:1(````'```$_0``
M`!`-:6D0`````@``!1,```````+!,````10```````+%4```,A,```````+%
M6```61,```````+!<```&14```````+!?```2Q4```````+!B```5A4`````
M``+!E```6A4```````+!H```-Q4```````+!K```6Q4```````+!N```314`
M``````+!Q```!!4```````+!T````14```````+!W```.Q4```````+!Z```
M(A4```````+!]```+A4```````+"````#A4```````+"#```6!4```````+"
M&```5Q4```````+")```1!4```````+",```"14```````+"/```0!4`````
M``+"2```*Q4```````+"5````Q4```````+"8```5!4```````+";```514`
M``````+">```&A4```````+"A```"A4```````+"D```'Q4```````+"G```
M,Q4```````+"J```0A4```````+"M```0Q4```````+"P```*!4```````+"
MS```"Q4```````+"V```!14```````+"Y```&Q4```````+"\```!A4`````
M``+"_```%Q4```````+#"```.A4```````+#%```,14```````+#(```'A4`
M``````+#+```/!4```````+#.```214```````+#1```4A4```````+#4```
M!Q4```````+#7```)A4```````+#:```414```````+#=```/14```````+#
M@```3Q4```````+#C```#!4```````+#F```3!4```````+#I```&!4`````
M``+#L```)Q4```````+#O```/A4```````+#R```1A4```````+#U```-14`
M``````+#X```4Q4```````+#[```%!4```````+#^```114```````+$!```
M3A4```````+$$```(!4```````+$'```-A4```````+$*```"!4```````+$
M-```.!4```````+$0```1Q4```````+$3```*A4```````+$6```%14`````
M``+$9```'!4```````+$<```+Q4```````+$?```,!4```````+$B```(14`
M``````+$E```#Q4```````+$H```/Q4```````+$K```2A4```````+$N```
M#14```````+$Q```%A4```````+$T```$14```````+$W```-!4```````+$
MZ```(Q4```````+$]```*14```````+%````+!4```````+%#```$A4`````
M``+%&```014```````+%)```)14```````+%,```$!4`````G>._H"\``&M`
M``#"K@7@G`,```""&&`$P@7``8"@8``"@``$`0```$``:T@!````0```X@$`
M``!```[(`0```(''X`B!Z````````````````````````)WCOYB0!Z!$D@>@
M2/`GH$24!Z!,\B>@2$``:_;T)Z!,$P``L!$``+"2$F'$D!(C+$``#GR4$``)
M0`!K9Y`0(`#"2@``@*!@`!)(`!$!````0`!K7@$````%``"U@*(@``)``(#0
M(*&,0`!K?P$```!``&OCD!`@`$``:T[0`@``0`!KP0$```#`*@``0`!KW)`0
M(`!``&M'T`(``$``:]L!````@A``")`0(`#$"$``A!"@`D``:]+$*$``0`!K
M/=`"``!``&O1`0```,(*``"$$"``@A!@`<(J``#0!Z!$`P``59`"(`6&$``(
MQ#^_^`4``%71'[_XE:`1"-$88!"5HHA(T1B@&(&JBL@M0`!1$0``5$``:Y^1
M*B`"^@>@2`D``+7$!Z!$@A``",8'0`#0(2&`B!`@!("@H`'&(@``!P``5(80
MX]C&(B`$!P``5880X"#&(B`(!P``5(80X^#&(B`,!P``M01```O((.&$B!``
M"(80(`'X!V`$A@#@`;H'8`2`H,`"^"$@$!)/__N(`2`$A`"@`SL``+64$``"
MT`=AC!,``$V%**`"DA)B()80``&8$"``0`!JR,`@0`*PDB```D``$`$```!`
M`&M*T`=AC!$``%1```8"D!(A2("B(``"0``,.0``M4``:K70!V&,0`!K#0$`
M``"!S^`(`0```$``:M;0!V&,$&__\+`0``C0!R&(@*(@`")```81``!40``-
MOP$````0;__P`0```$``!>N0$B#0@*(@``)/_^O0)R&($&__]P$````3``"Q
MD!(CT$``:TB2$F%80`!K=I`0(`$!````,&@`!0$````!`````0````$```"\
M$```G".@&-(#H%B4`Z!<$0``11<``%,9``!3D!(@X)82XT"8$R/`FA```4``
M:KL!`````````('#X`BN`\`7G>._H#4``+'"#J%L@*!@`!)``!HW``"P.0``
ML+86X`BX%R`,.P``L;@G`!O"!V%PN3\@`K@'/_^`H$`<.D``#H(0(`&Z%V%P
M@@!@`<(G0`"#*&`"P@;``9_`0``!````P@=``("@0!P*3__Y@@!@`8(0(`'"
M+J%L@<_@"`$```"=X[^@@<_@"`$````P:``%`0````$````!`````0```)WC
MOZ`1``"PP@(@$("@8``"0``)D!(@$`,```""$&``@*!@``)```0!````G\!`
M``$```"!S^`(`0````$```"=X[^@@<_@"`$````P:``%`0````$````!````
M`0```)WCO6"$$"``B`8@'(('OL#&`0`"QB!``H0`H`2`H*!`,D___<8!``*$
M![[TM@>_]/@`O^S&`(``^@"_U,@`O\R&'P`#AAC`'888P`2),.`?A@#``X81
M``/&(*`,A`"@!("@@!LR3__T^`"_[-X&```)%J">!QNV>M`&(!"($2&9AA#C
MH=H'OL"[,^`;!2/&[]8&(`2Y*^`%A!"@W-(&(`B:`@`-N!<`'=0&(`R:`T`$
MN@I`"_8`8`2:`T`<M"J`"Y@J0`_R`&`,N2K@'KH6@!WD`&`(M3+@`K8"@!OL
M`&`0M!:`'+H#0!W:`&`4N`Z`#[8&P`3J`&`LN!,`'+(&0`3H`&`HF2]@!;8&
MP!SN`&`8N3=@&Y0N@!W@`&`<N!,`'+(&0!KF`&`@M@;`'*0"0!+B`&`DN2O@
M'J0$@`2U,^`"K`6`!+06@!R:`T`$N`]`&JP%@!J9-N`;N!*`')$NX`6N!<`$
ME2]@'I`2``R[-V`"D`2`"+H70`JX`@`<F"Z`&[0.P!V0+T`<F!,`&IH#0!VR
M!D`,M3<@&Z`$``2[+R`%I@3`!+H70!JT!4`$E`9`';(%``3H`&"`I3*@&Z($
M0`2K*J`%Z">^"+LNX!ZJ%4`2MS;@`JH%@!7L`&"$J2\@'K86P!WZ`&!XF`\`
M&^PGO@RD+L`*[`!@C+DW(`*N!<`;N!<`%)@2``SH`&"0M@J`'.PGOA28!4`,
M[`!@E*04@!N@!``<Z@!@B)H#0!+V`&"8I3,@&^PGOASL`&"<ZB>^$*HO``SH
M)[X8N2L@!?8GOB"D%P`2Z`!@,)H#0!+0`&!\[">^)+8%``3L`&"@D`(``^@`
M8#3L)[XH[`!@/+@%``3D`&`XZ`!@I*P%@`2D!(`$[">]Q.P`8$#D)[W`I2J@
M'N@GOBR5,J`"K`6`!.@`8*B4$H`2Y`!@L.@GOC#L)[W(Z`!@K.P`8$3D)[XX
MY`!@M*P%@`3H)[XTJ`L`"NPGO<RM*V`%JA5`%.0GOCRE,V`;Z`!@N*P5@!*D
M*H`-K`7`%I0$P`KF`&#(Z">^0*H%@!7H`&"\[`!@Q.@GOD2I*R`>F3,@`NPG
MODB8$P`4[`!@S*@+0`SF)[Y,IBL`%9@$0`SB`&#0I!2`%.PGOE"@!``2[@!@
MP.(GOE2C+6`%Y`!@U*X%P`+L`&!(Y">^6*4U8!NH!8`$HA1`$NP`8-CD`&!,
M[">^7*P$@`3(`&#<Y`!@5,@GOF"(!``1X`!@4*0$@`/B`&#@H`0``^0GO=3D
M`&!8X">]T*$K8![B)[YDFS-@`J0$@`/B`&#DFA-`$.``8.RR!D`-XB>^:.0G
MO=CB`&#HY`!@7.`GOG#@`&#PI`2``^(GOFRB#4`-IA3`$>0GO=SB`&#TI2D@
M!>`GOG2A,2`;I!2`$.(GOGB@*T`$X@!@^)0"@!+D`&#\E`*`$^8`80#B)[Y\
MHRU@'N0GOH"K-6`"YB>^A*H50!':`&$$H@D`%;0&@!7D`&$(H!0`$>8`80RC
M*J`%F`,`$-HGOHBA,J`;FBU`"N0GOHR@%$`0Z@!A$)@#`!#D`&!@X@!@9.8G
MOI"F!(`#ZB>^E.0`81CJ`&$4X`!@:.HGOIBJ!$`#Y">^G*`$``/B`&$<Y`!@
M;.(GOJ"D!(`#X@!A(.`GO>"A*2`>Y">]Y(DQ(`+D`&!PB!$`$.(GOJ3@`&$H
MI`2``^(`823D)[WHXB>^J*(*@`3D`&!TFA-`$>`GOJS@`&$LI`2``^(`83#D
M)[WLI2L@!>`GOK"A,R`;XB>^M*04@!"@*0`,X@!A-+(&0!*(!L`$L@9`#>0`
M83CB)[ZXHRJ@'I4RH`+"`&$\FRY@!902@!&V"P`*N`<`"L(GOKRV%``;@BJ`
M&;8&@!N4!T`#M39@&[LK(!ZT$T`:V@>^#)DS(`*V!L`:]`>^")@3`!WZ![X4
MH@-``YLNX`6@!H`#]`>^$+H'0`/Z)[WTNS;@&[0&@`/T)[WPM`Y`#)H30!V"
M$$`:NBL`&[4N8!Z(`0`-V@>]Q+,V8`*"`0`!R`>]P+(60!JT#L`9F`$`#+H7
M0!J(+D`!M2A@!;H'`!VY,&`;L@-`&=H'OABX%H`<]`>^'+H'0!SX![X@F@-`
M`[0&@`/:)[W`N`<``_@GO?BY+N`>V@>^)+<VX`+T)[W$MA;`'/0'OBB&`T`#
M^`>^++0&@`+&)[W\]">^`(<W8!NX!P`"M2]@!?@GO@2X"$`;B!$`'+06@`/:
M![W,N2A@'K0#`!K8![W(@S!@`H@&@`2"$$`<AB[`';0/0`&X*$`$AA#`&H(#
M0`':![XPM2D@!88&0`.S,2`;M@,`&[06@!GR![XTF`-``H8`P!KT![XXV@>^
M/+(&0`*T!H`"\B>]R/0GO<RU+V`>F@-``KLW8`+:)[X(\@>^0)LHX`6Z%T`:
M]`>^1+(&0`+R)[X,M`:``K()`!WT)[X0M3#@&[@7`!FS*2`>FA-`&HDQ(`*T
M+T`#B!$`&;8&P`W:![Y(L@C`!+@&P!RT%H`9N@4`';,O(`6"`$`:M3<@&Z@#
M0`+:![Y0M!9`&O('ODRV*0`<@@!`&H@%@`2U*.`>K`9``O('OE2',.`"F@-`
M`MHGOA2&$,`:]`>^6+(&0`*;*&`%\B>^&+(/``.T!H`"]">^'+86P!FU,&`;
MLR\@'IH30!JZ!T`-M"C``=H'O=2Y-R`"N@=`&_8'O="X%P`9A@;``[8(0!RV
M%H`;]`>^7+(#0!S:![Y@B`$`&[<W8!NT!H`"]">]T+4O8`6:`T`"VB>]U)LH
M8!ZV%H`;]`>^9(,P8`*(`0`;@A!`#=H'O=BT!H`"]">^(+@80!RV`T`!]`>^
M:+@?`!W:![YLA@#`'+DQ(!NT!H`"]">]V+4I(`6:`T`"VB>^))LO8!ZX%H`<
M]`>^<+LW8`*&`,`<^`>]W+H70`V$!H`"V@>^=((?0`'$)[XHA`<`';DHX`6T
M&$`$`S*8L+(&0!JU,.`;@A!AUIH#0`&X%P`:VB>]W)LI(!ZX!D`<]`>^?(DQ
M(`+R![YXI`2``8@1``VT!H`!NAD`';(&0`'R)[XLNA]``_0GOC"F!,`$M2\@
M!;H&P!W:![Z`LRC@'K<W(!N:`T`!VB>^-(<PX`*V%H`;]`>^B(80P!GR![Z$
MN@=`&X@8P`2T!H`!V@>^C+(&0`&(&0`<\B>^./0GOCRW+V`%A`"`!+4O(![R
M![Z0J@5``XDW8!N:`T`!VB>^0+DW(`*(%L`$]@>^E+@7`!JR!D`!]`>]X(8?
M``.$`(`$\B>^1+8&P`':![Z8AAC`';,O8!Z(!H`<]B>]X+LW8`*&!,`#NA=`
M&?('OIRF`T`!M3"@&]H'OJ"X'T`<MRB@!;(&0`'R)[Y(MA;`&O0'O>2:`T`!
MA@#`&]HGO>2X'P`"M@:`'=H'OJ2X!4`<LS#@&[4HX`6J`T`!FRB@'K06@!GR
M![ZHA3"@`K@'`!JR!D`!A!"`#?(GODSR![ZLNAB`'=H'O>BZ'T`#L@9``8@!
M`!WR)[WHNS<@&[0#0`+:![ZPLR\@!;H60!WR![ZTF@-``=HGOE";*.`>B`$`
M'8<PX`*R!D`!\B>^5(80P`WR![ZXV@>][(08P`*R!D`!A!B`'/(GO>RZ`T`#
MA`;``K,I(`6;+R`>MS$@&[DW(`*V%D`;N!<`#80`@!OV![Z\AA\``Y0"@!R&
M&,`$G@/`&[0&@`.:`\`!ARD@'HDQ(`*W**`%B!$``X,PH!NX&0`<@A;``;@?
M``*"!H`!N@=`'(<HH!Z0`@`$A3"@`K4P8!N$$(`#MRA@!888@`2V%L`:AAC`
M`;H'0!N4`H`#B2A@'J`$``*#,&`"MR]@!8(00`2Y-V`;A!A``H86P!RV&(`=
MA@*``Z($0`'4![W`A2]@'K8"`!O0![WTNS=@`KDHX`6Z%T`"B3#@&X(?0`&(
M%P`$@AA``_@'O?"V!L`$H`0``8DHX!Z$!P`=AS#@`K4NX`6&$,`$N3;@&[H8
MP!V"%H`<LA]`&[LNX!Z"!``!X`>]Q+<VX`*(`@`#T`>^`+86P!VR!$`9X@>]
M^+4P8!N&'L`#N2A@!888P`&X%P`:A`"``[(&0!RZ`H`;U`>^!(<H8!Z#,&`"
MM2Y@!8(00`.Y-F`;MAA`&[@6@!R>'L`9A`"`'(8$``'@![W(MRY@'H@!``^S
M-F`"M3"@&[(60!NY**`%@AY``;@7`!J"&$`"B`$`'+H'0`&W**`>N`1`&>('
MO<R%,*`"GRD@!800@!OV![W\M3$@&[(8@!F"$\`:LAY`!(('0`&Z!L`"MRD@
M'H8`P!F),2`"GS!@&X@1`!NU*&`%A!D``K06@`^$&(`!A@#`&K@'``*S*.`%
MM@(`!-`'OA"%*&`>M3#@&X,P8`*T%D`:@A!``K@'`!J(&$`$L@*``=0'OA2U
M*.`>A3#@`H89``.$$(`:N@=``[4O(`6&$(`!B3<@&X8(P!R(%H`$@@B``8@'
M0`2"$,`!NR\@'K8&P`&Y-R`"F`,``H<I(`6X%P`=NS$@&X(7``*&$,`=@@A`
M!+LI(!Z&!L`#B3$@`H0/``*($0`=@A!``K<HX`6$$0`<NS#@&[(&0`&$"(`#
MNA;`';<HX!ZZ!D`=\@>^"(<PX`*"!``<X`>^'(80P!NX"0`<M2]@!800@!RW
M-V`;N!#`!)@#``*V%H`;A`1`!+@/`!WB![W0B`C`!+8#`!O8![X8M2]@'K@7
M``2[-V`"B`9``[H70!J"`$`<LR[@!;@70`.U-N`;N`\`&[060!J&#T`#@@!`
M&H87``/X![X,M2[@'H0`@`.W-N`"A@<`';,H8`6V%L`:M3!@&[@6P!VT%D`:
MN@[`'80`@!JX#P`!M2A@'K@7`!V#,&`"B`$`'((00!JZ`@`;T`>^*+,HH`6X
M$$`;M3"@&[8(0!NT%D`:N`\``H@!`!JX%P`;M2B@'H8`P!R%,*`"K@7``;<I
M(`6$$(`:N!"``8((@`&U,2`;N`\`!+86P!JX%P`!A@#`&[H'0!RW*2`>J`4`
M`HDQ(`*Y,.`;B!$`&[<HX`6"$0`"N!;`'(0)``*Z!T`<@@A``[DHX!Z"$$`"
MAS#@`JX%P`&&$,`<K`6`!+DW8!N"$,`$A2]@!8@(P`2$$(`<@@A`'80%P`*"
M$$`$N2]@'J@%``&[-V`"@@*``]0'O=RW**`%NA=`'+DPH!N(%T`#N!;`'(@)
M``*X!0`<A@]``^@'O=2W**`>AA$``X4PH`*L!8`#A!"`&X8#`!W8![XLM2\@
M!8@0@!VW-R`;N@B`';86@!N("0`<M@6`&X@1`!WL![X@M2\@'H(`0`2Y-R`"
MB`0``N`'OC"S+N`%N!<`&K4VX!NZ%P`"M!9`&KH/0!N"`$`:A`\``K4NX!Z$
M%T`"MS;@`H8`P`*V%L`:A`1`'.('OC2S*&`%NA;`'+4P8!NX#L`<M!9`&KH/
M0`&&`,`:NA=`'+4H8!Z(`0`=@S!@`KH%`!OH![XXLRC@!8(00!JU,.`;N!!`
M&[060!JV"$`;B`$`&K@/``.U*.`>N!<`&X<PX`*$`(`<AA#`&K@%@`'L![X\
MLRD@!;80P`&U,2`;@@C``;060!JV#L`$\@>]V(0`@!JV%L`!M2D@'H(&0`.)
M,2`"N@=`&[,HH`6($0`:M3"@&[81``.V#L`"M!9`&H8)``.Z!T`:M2B@'H86
MP`/V![XDA3"@`K@'``.$$(`:A@;`!+,O8`6V$(`$M3=@&X@(@`2T%D`:M@[`
M';@'`!JV%L`$M2]@'H(`0!N[-V`"B`(``M`'O>"S+R`%NA=`&K4W(!NV%T`"
MM!9`&K8.P!R"`$`:A`]``K4O(!Z$%L`"N3<@`H8`P`*X%P`:A`*`'=0'ODBS
M*&`%MA<`';4P8!NZ#P`=M!9`&K8.P`&&`,`:MA;`';,HX`6(`0`;NRA@'K0#
M`!S8![WDMS#@&X,P8`*V%D`;@A!`'8@!`!NX&$`<N@0``>`'ODRS,2`;GA\`
M`[<I(`6$`(`/N2C@'K86P!F',.`"A`"`&Y\HH`6&$,`<@AC``;@$0`/B![WH
MLS"@&X(80`2W*2`>M`:``8DQ(`*"$\`9B!$`&X(&@`&&&0`#M@4`!.@'OE2S
M,&`;GAC``K4H8`6Z!T`/ARB@'K06@!F%,*`"N@=`&I\O8`6$$(`#AAB`!+0%
M@`+L!B`0LS=@&X88P`&)*&`>N`<``X,P8`*&$\`9\@>^0((00`2&!P`#A!A`
M`H@&0`&Y*.`%GAB`';,PX!NV!L`/A2]@'K@7`!F[-V`"M@;`'/@'OD2?+N`%
MNA=``H(?0`&$!P`=N2C@'H(80`.',.`"M`:``;,VX!N&$,`<NAC`'8(3P!F>
M'T`;@@:``;LNX!ZX`@`#MS;@`H@!``^S,&`;MA;`'88>P`.F!,`;M2A@!;H8
MP`&T%H`9A`"`';LH8!Z(`0`:@S!@`K4I(`6"$$`=MAA`&[H"@`&',2`;LA[`
M!(86@`.X!P`9MRD@'H0`@`.),2`"M3"@&X@1`!N'**`%@AD``;880`*&$,`:
MA@<``Z8$P!NW**`>N`,`!(4PH`*U*.`%A!"`&X,PX!N(&(`$@A:``8@9``."
M!,`!J@5``N8'OE"W*.`>N@=`!(<PX`*S*&`%AA#`&[4P8!N$&,`"B!9`&K0$
M``.(!T`$NAB``;<I(`6X!P`=NRA@'H,P8`*%,2`;@A!`'8880`.$%L`"A`<`
M`KH8P`2W*2`>N@5`'>H'O>R),2`"N`1``9\HH`6($0`;LS"@&X(9``&&$\`9
MM@3`!(8'0`.Z&$`"LRC@!;0&@!V[**`>A3"@`H,PX!N$$(`=@A9``8@8@`2"
M!H`!B!D``[4HX!ZX!P`$AS#@`KH%``*?*&`%AA#`&K,P8!N$&,`"B!/`&;0%
M0`.(!P`$N!B``;,I(`6V!L`<N2A@'H,P8`*%,2`;@A!`'(060`*&&$`#A`;`
M`H88P`2Y*2`>N@=``XDQ(`*V!(`!GRB@!8@1`!RS,*`;@AD``883P!FX`T`$
MA@=``[H80`*S*.`%M`:`';LHH!Z%,*`"@S#@&X00@!V"%D`!B!B`!((&@`&(
M&0`#M2C@'K8&P`2',.`"N@"`%K,P8!N&$,`:GRA@!808P`*($\`9A!B``?(&
M(`R(!L`$N`<``I8!``N&`,`9MRD@!84H8!Z),2`;@S!@`H@6P`2"$(`!B`<`
M!,@F``"2`$`)UB8@!,8F(`S2)B`(^B8@$('/X`@!````,&@`!@$````!````
M`0````$````!````G>._H+H0`!B`IV```D``)K`0(``#``"QX`!A4("D(``"
M0``A`0```,)/0`"$&&`]@*```H1`(`"`H``!@D`@`("(@`$22``:M!`@`/@$
M``"`IR```D``%+`0(`"V$``0D!``')(0`!U``&6;E!``&H"B(``R2``'M@;@
M!,)/`!J`H&`](D``%[8FP!"V!N`$^`;``("G(``23__SD!``'+`0(`"!S^`(
M`0```((0`!W$2&`!M`!@`888H#V`H``#AD`@`("@``*$0"``@(C``A)/__B"
M$``:$&__W;0F@!VT!J`!MS[@`O8F0`"!S^`(D`,`"C!H``,!`````0```)WC
MOYB0$``8?___OI('O_R!Q^`(D>@`"`$````!````G>._F#L``+&0$``8?___
MM9('O_R`HB```D``%,8'O_S(!V%0ARC@`H(!``/$`&`$@*"@``)'__7$(0`#
MQ`!@",0@8`2`H*``$D___8(`8`20$``8?___HY('O_R`HB``$D__\,8'O_R!
MS^`(`0```#!H``0!`````0````$```"=X[^@0`!E7I`0(`!``&3)T`(``$``
M9((!````P@(``)`0(`!``&56^@!@!$``9,'0`@``0`!DFP$```#X"@``0`!E
M3Y`0(`#0`@``0`!DN;@/(']``&26`0```,("``"0$"``P@!@$(,P8!>#*&`'
MN!<``4``94+X-V`"0`!DK=`"``!``&1F`0```,("``"0$"``0`!E.OH`8`1`
M`&2ET`(``!,``%24$"``0`!E')(281#0)V`<0`!E,9`0(`!``&2<T`(``$``
M9%4!````P@(``)`0(`!``&4I^@!@!$``9)30`@``0`!D:`$```#"`@``D!`@
M`$``92'")V`@0`!DC-`"``!``&1%`0```,("``"0$"``0`!E&?H`8`1``&2$
MT`(``$``9.@!````Q`(``("@H``"0``*@A`@`$``90^0$"``0`!D>M`"``!`
M`&3>`0```,("``#"`&!LPB=@)$``90:0$"``0`!D<=`"``!``&0J`0```,("
M``"0$"``P@!@!$``9/W`(&`H0`!D:-`"``!``&0A`0```,("``"0$"``P@!@
M!$``9/3`(&`80`!D7]`"``!``&08`0```,("``"0$"``0`!D[/H`8`1``&17
MT`(``$``9-P!````P@(``,(G8"R!S^`(`0```#!H``,!`````0```)WCOSB`
MIB```D``4P$```#"3@``@*!@``)(`#Z0$``80`!D7S<``%2V%N!@,P``/+J2
M(``"0``W-0``$$``9&V0$``=@A``")`0`!B`H&```D``+*``8!/$"&`3@*"@
M+B)(`"[$"&`40`!D:P$```"X$``(0`!D:)`0`!"0!P`(0`!D@Y`"(`*6$``;
MF!``&)H0`!"2$"`!E!`__T``9*^X$``(DA``')0'OYA``&/ZD!`@`X"B/_\"
M0``'D!``',('OZB""$`9@*!`&@)``!X!````0`!D4P$```!``&0AD!``'$``
M9$.0$``=@A``")`0`!B`H&``$D__V*``8!-``&17D!``'4``9&J0$``8@<_@
M"`$```"`H*```D__R("@H"X23__1`0```,((8!6`H&```D__P@$````0;__+
M`0```'___Z\!````$&__Y`$```"!S^`(`0````$```"=X[^@D!`@`$``9(6Z
M$"``0`!C\-`"``!``&17`0```)00``B2$``80`!C_)`0(`.`HB```D``!`$`
M``"!S^`(D!``#4``9'8Y```\0`!CX=`"``!``&1(`0```,0"(!`#```0A`B`
M'("@@`$B0``.D!``&$``9&J0$"``0`!CU=`"``!``&0\`0```,("(!"X"$`<
M`P``*("G``$23__HD!``&$``8^"2$"`"@*``"+I@/_^!S^`(D!``#0$```"=
MX[^8PDY``+H0`!B"&&`]@*```;)F?_]``&/WD!``&;80``B2![_\?__^AI`0
M`!BXDB```D``6#4``+%``&/N`0```/`'O_R"$"``@*;`"`A(`$FQ+B`"PD]`
M`(088#V`H``"A$`@`("@``&"0"``@(B``0)```Z&$"``@A``'<1(8`&&`&`!
MB!B@/8"@``2(0"``@*```H1`(`"`B0`"$D__^((0``.&(,`=M@;@`O@&H5!`
M`&/ND`;``]`G`!B`HB```D``*K`0/_\#``"QQ`]``,8`85#"![_\B2B@&(DY
M(!B#*&`"@*$@`,(`P`'$*$```D``$X80``&`H2`]`D``$+H'8`$0:``&Q`]`
M`("@H#T"0``,A!`@/<0/0`"&`&`!N@=@`8DHH!C$*&`!A3D@&("@H``23__V
M@A```X00(#V"$"``Q"C``,0.0`&Z`,`!@@!@`8DHH!B`H2``$D__^\0O8`&P
M$"``@<_@"`$```#$#D`!Q"\``84HH!B`H*``$D___((`8`&!S^`(D!`@`)(0
M(`CB!J%0P@1``("@8``"0``*N!`@`((0`!&"`&`$Q`!``("@H``23__]N`<@
M`9('(`*3*F`"`P``L<0`87B`H*```D@`#X00(`&0$``10`!C'K`0/__0)J%0
M@*(@``)'_]Z@$``(L2\@`H('(`&#*&`"P"0``1!O_Y/X)[_\D!``"4``8Y7$
M(&%XH!``"("B(``"1__1L!`__[$O(`*2$``10`!CI900`!@0;__PX":A4#!H
M``8!`````0````$````!`````0```)WCOZ"0$"``0`!CO3,``%30`@``-0``
ML#<``%2R%F!H0`!C)+06HR"P$``($(!CKI?NX(@P:``#`0````$```"=X[^@
MD!`@`$``8ZTW``!4T`(``+86X1`S``!4-0``4D``8Q2Z$"``?___YK(68)A`
M`&.CD!`@`-`"``"T%J#`0`!C#+@0`!L0@&,TD>@`"#!H``0!`````0````$`
M```#/__W@A!CD)WC@`'"`>`4PB>__((0(``Y/__W0`!BNSL```2X%R/P%P``
M5+@'@!P;``!4F!``")(0(`&0$``<E!=@`982X+!``&-\FA-@P("B(``&0``4
ML!`@`)`0`!PY/__[N!<C^)00`!VX!X`<0`!C5)(0`!RZDB``!D``"@$```!`
M`&,ZD`=@`;"2(``"0``%DA``'$``8Q&4$``=P"X`'<0'O_S"`>`4A)B``8(0
M(``20``$`0```('/X`@!````0`!C,`$````!````,&@`!`$````!`````0``
M`((3P``0O__'`0```#!H``4!`````0````$````!````G>.P`!$``%2<`[^0
MP@'@%,(GO_R"$"``?__]RI`2(-"Z$``(DA`@+T``8IR0$``8@*(@`")```Z0
M$``8$0``5)(0`!A___[OD!(@X,0'O_S"`>`4A)B``8(0(``20`!J`0```('/
MX`@!````0`!BXC4``%2@$``(DA:@\$``8PB0$``9I)(@``)'_^TY/__[(P``
M5+@7(_@S``!4-P``5+@'@!RB%&#XLA9A`+06H/#$3(``@A;@R("@H`"E9$`!
M@*=@``)```>0$``=0`!C*I(0`!*`HB```D``-P$```!``&+%D!``$H($@`C"
M2'__@*!@+S)```J0`B`!D`(__\`L@`B"!(`(PDA__X"@8"\B3__\D`(__Y`"
M(`&0`@`0@*(O_Q1'_\:2$"`!%0``!/`CH%R6$``1F!``$IH0`!E``&+^D!``
M'$``8P60$"``0`!B<-`"``!``&+7`0```)00``B2$``<0`!B0Y`0(`.`HB``
M,D@`$)`0(`!``&+X`0```$``8F/0`@``0`!BR@$```#$`B`0`P``/(0(@`$#
M```@@*"``0)```J0$``<D!`@`$``8KJ2$``:I)(@`#)/_[W$3(``$&__GA$`
M`%1``&)EDA`@`8"B(``R3__VD!`@`!$``%22$``<?__^A9`2(.!``&+FD!``
M'!!O_Y2P$``(0`!BH`$````!````,&@`!`$````!`````0```,0*``"%**`8
M@*"@``)```N"`B`!A3B@&("@H"^19$`!@@!@`<0(?_^%**`8@*"@`!)/__J%
M.*`8@</@"`$```"=X[^@@*8@``)``#0!````PDX``("@8``"2``P`0```$``
M8EV0$``8D`(__X0&``B`I@`"&D``3((0``+"3@`(@*!@+R)(``B"`+__$&@`
M2((0``*`H.`O$D``+800``&"`+__@*!`&#)/__O&2+__A!```8"@@!@B0``K
MPDB``)0`O_^`I@`*.D``!Y0B@!C"2+__@*!@+P)/__J$$``*E"*`&!<```2"
M`J`"@*!`"QA```B0$"``.P``L9(0`!B0%V&`0`!API0"H`&0%V&`@<?@")'H
M``A``&)-D!`@`H"B(``"1__[`0````,```N"$&(`PC(``(''X`B1Z``(@*#@
M+P)'_]R"$``"A`!__X"F``(J3__[QDA__Q!O_]>`H(`8@*!@+P)```0Q``!4
M$(!B?Y'N(0!``&(UD!`@`H(0``B`H&```D?_XI`0(``%```+D!```800H@`0
M;__=Q#!``!!O_\2$$``!$&__Z80`?_\P:``#`0````$```"=X[]X!0``5!$`
M`%2"$*/HQ!BCZ)`2(0C8&&`(.P``5#,``%34&&`0.0``5#$``%3T&&`8PA!@
M(,@!X!3()[_\B!`@`,0_O]C8/[_@U#^_Z,(WO_A___S+]#^_\!$``%1___S(
MD!(A&!$``%1___S%D!(A(!$``%1___S"D!(A,'___,"0%V$X$0``5'___+V0
M$B%(?__\NY`68-!___RYD!<A6'___+>0%B%H$0``5'___+20$B%X$0``5'__
M_+&0$B#@$0``5'___*Z0$B&($0``5'___*N0$B&8$0``5'___*"0$B&HDI(@
M`")```41``!4?__]RY`6(6@1``!4?__\F)`2(<"`HB```D``!9(0``@1``!4
M?__]PI`2(=@1``!4?__\CY`2(>B2DB```D``$!$``%1___VZD!9@T!,``%20
M%V$X?__]MI(28B#"![_\Q`'@%(*80`*$$"``$D``&0$```"!S^`(`0```'__
M_'R0$B'XDI(@`")```83``!4?__]IY`7(5@0;__N$P``5)`'O^F2$F(00`!A
MYI00(`J`HB``,D__YQ,``%20%R%8?__]FY('O_,0;__B$P``5$``8;@!````
M`0```#!H``0!`````0````$```"=X[^@.P``L?`'842`IC__$D@`$!$``%2P
M$"``?__\69`2(5B`HB``(D``"O`G843"2@``@*!@`")(``;P)V%$@AA@,("@
M``&P0"``\"=A1('/X`@!`````0````$```"=X[^@0`!A@+`0(`!``&%X`0``
M`("B(``R2``"\`(``('/X`@!````,&@`!@$````!`````0````$````!````
MG>._@`,``%0[``!4@A!B.,(GO^PU``!4`P``5#<``%2"$&)`PB>_\+H78B@#
M``!4^B>_Z+@'O^R"$&)(PB>_]+06H/@#``!4MA;@\((08E#")[_X`P``5((0
M81`0:``,PB>__$``86<!````@*(@``)``!L!````^@<``,)/0`"`H&```D``
M%+@'(`1___P5D!``':`0``B`HB```D``!I(0`!C"2@``@*!@`!)/_^X!````
MD!``'7___3J2$``8^@<``,)/0`"`H&``$D__\+@'(`2!S^`(`0```$``82Z0
M$``8LA``"$``82N0$``0D`9`"$``84:0`B`"X".@7)(0(`&4$#__EA``&I@0
M`!B:$``;0`!A<;(0``B0$``=?__]()(0`!D0;__5^@<``#!H``0!`````0``
M``$````#/__?@A!BL)WC@`$)/__?-0``5+81(SRT%J)X^@'@%/HGO_RZ$"``
MA`>`&_0G@!LW``!4MA;B@#L``%3V(*`$-P``5+(1(R2Z%V$0MA;@R/H@H`SV
M(*`(!0``5(('@!F$$**(Q"!@!(@1(TP%``!4A@>`!/H@8!2$$**0Q"!@"#D`
M`%0%``!4D!<@T/H@X`B$$**8Q"!@##4``%0%``!4-P``5(00HJ#$(&`0`P``
M5((08JC"(.`$M!:AV+86XFCT)X`9?__[M_8G@`2RDB```D``!@$```#"3D``
M@*!@`!)``-L!````?___9@$```"BDB```D``W"$__]_V#$``MR[@&("FX``"
M0``3(3__WT``8+D!````@A``$880(%_$`@``MS[@%\00@!N`B*@`(D@``L8H
M0`""`&`!]@A``+<NX!B`IN``,D__]\0"```A/__?LA`@`9`0`!H0:``(H!0C
M)(('@`'0`$`0PDH``("@8``"0`"5L@9@`7__^XD!````MI(@``)'__>#+F`"
M?__\A`$```"`HB```D__\H,N8`)``&$2D!``&[:2(``"3__M@RY@`I`0`!M`
M`&"F(0``5+(0``A``&"CD!``$;(&0`BR!F0$0`!@O9`0`!FT$``(0`!@NI`0
M`!GB(Z!@%P``5`,``%2"$&+(E!`__\(CH%R6$N*XF!``&YH4(0"2$"`!0`!@
MX;(0``B2$"'M0`!@%9`0`!D1``!4?__[79`2(DB`HB``(D``"O8&``!``&#K
M]@8``)(0``A___V%D!``&[:2(``B0``"]@8``$``8'V0$``;@*(@`P1(`!"B
M$``(D`(__!,``%20!L`(0`!@U9(28M"`HB``$D@`"("D8`0"0`%OH@;`$<),
M?_N`H&`O(D`!;/`&(`1___[=`0```("B(``22``)$P``5)`0`!M``&"ODA`@
M`**2(``R0`![$S___Q,``%01``!4DA)B('___%^0$B%80`!?WS$``%3Z(Z!@
M%P``5-`CH%R:%"$`DA`@`9`0`!J4$#__EA+B^)@0`!FV$"``0`!@GZ`4(0`0
M:``4L!8C"$``7\D!````P@(``("@8!$20``4`0```$``7\FV!N`!^B.@9-`C
MH%R2$"`!D!``&I00/_^6$``8F!``&9H0`!!``&"+]B.@8)`0`!I``%^_DA`A
M[8"B/_\"3__J`0```$``8`60$``9D!<@T'___#*2$``:?__^R)`0`!KZ![_\
MP@'@%+J?0`&"$"``$D`!<;`0`!J!S^`(`0```#,__]^R%F,\]@>`&<).P`"`
MH&``$D@`"K00(`$0;_]UMA`@`(('@`'V`$`9PD[``("@8``"0``2M`:@`7__
M^^>0$``;@*(@``)/__>#+J`"0`!@=9`0`!NVDB``$D?_98,NH`*"!X`!]@!`
M&<).P`"`H&``$D__\K0&H`$0;_]=MA`@`'___IT!````0`!@9I`0`!D0;__3
MM!``"+(0(`&0$``;H!0C3'__^LP!````@*(@``)```>#+F`"0`!@6@$```"B
MDB``$D?_&X,N8`*"!X`!T`!`$,)*``"`H&``$D__\K(&8`$C``!4$&__)Z(4
M8G`5/___,3__WY02H^Z6$"`"L!8C6)(28_]``%^/M@>`&)`0`!&4$"`&0`!?
MII(0`!O"#X`8@*!@`!)```>0$``1P@[@`8"@8$,B0`#YP@[@`I`0`!&2$"``
ME!`@`$``7WZ6$"``P">_;`,9T4@Q/__?P">_<((08P'")[]8L!8C6`,[\VK`
M)[^TL`>`&((08XG")[]<`R8NMX(08/[")[]@`P0,E8(08';")[]D`S#TN((0
M8?#")[]HD!``$9(0`!A``%^`%0``(+:2(``$0`!(W@>_;(DNX`.&$"``Q`>_
M<)LVX!VH$``8B`$`#\('O[2`H\`$R">_;(=G(`&`H&``A`"``X0`@`T"2``4
MQ">_<*@0($"$![]TJ"4``9``@`&2$``8@*;`%*ED@!M``%^5E!``%,('O[2"
M!0`!@*!@0!)/_][")[^TD`>_6+8FP!1___3=J`8`%("FX#\$0``8E!``&[8&
M_\"F!2!`JS;@!J00`!2#+6`&I@3``9(0`!*4$"!`D`>_=$``7WZD!*!`?__T
MS9`'OUB`I(`3$D__^9(0`!*#+6`&J@5@`:LM8`:V)L`!J`4`%900`!N2$``4
MEA`@1$``7SF0![]T]B>_M)`0`!&2$``80`!?.A4``""VDB``%$__O-X'OVQ`
M`%^`D!``$>('OVSD![]PB!`_@(,T8`.""&`_A`!@`88'@`&`H*`XR"C_=(0'
MOU@40`!ND`"``900(#>0`B`=DA`@`$``7Q64(H`!@S2@&,(OOZR0![]8@S2@
M$,(OOZVV$"``A31@&.0OOZ^P![^X@S1@$.(OO[/$+[^PHS1@",(OO[&E-*`(
MXB^_LB,``%3D+[^N?__TD:(48O#>![]8R`>_7,8'OV";,^`8Q`>_9)<SX!"8
M$``-P@>_:)$SX`B3,2`8VB^_Z)4Q(!#6+[_IFS#@&-XOO^N7,2`(T"^_ZI\P
MX!#2+[_LD3#@"-0OO^V3,*`8UB^_[I4PH!#(+[_OES"@"-HOO_#>+[_QFS!@
M&)\P8!#0+[_RB3!@",8OO_/2+[_TU"^_]=8OO_;$+[_WVB^_^-XOO_G(+[_Z
M$&@``\(OO_O8#L`!D`;`&Y(0(`&0!@`(E!`__Y80`!%``%]EF`L@_[8&X`&`
MIN`4$D__]H('O^@7``!4D!``&L`OO^"2$"`!E!`___`CH%R6$N+@F!``&?HC
MH&!``%]6FA0A`!!O_M$!````\`8@!("F(``"1_Z5`0```$``7OV0$``8@*(@
M`PA/_I"0`C_\$P``5)`&``A``%]6DA)BV("B(``0;_Z)MV1`&)00(#^2$"``
ME"*``4``7JF0`B`=?__T-Y`'OUC`)[]TP">_>,`GOWS`)[^`P">_A,`GOXC`
M)[^,P">_D,`GOY3`)[^8P">_G,`GOZ#`)[^D$&__A<`GOZB`H&!!$D__"9`0
M`!'"#N`#@*!@0Q)/_P:2$"``P@[@!("@8$@23_\#E!`@`,(.X`6`H&!%$D_^
M_Y80(`(3/___%3___Y`0`!&4$J/&0`!>=Y(28_^2$``;D!``$4``7HZ4$"`I
M]B.@7!<``%20$``:^B.@8)(0(`&4$#__EA+BX)@0`!E``%\+FA0A`!!O_H8!
M````0`!>V@$````!````,&@`!@$````!`````0````$````!````G>.P`,(!
MX!3")[_\@A`@`)P#OYA``%\"D!`@`$``7FW0`@``0`!>@P$```""$"`!PBH`
M`!$``%1___ERD!(A.("B(``"0``&`0```,)*``"`H&`Q(D``J,)*(`%___R1
M`0```$``7NZ0$"``0`!>6=`"```3``!4E!`@`9(28R!``%Y%EA`@"X"B(``"
M0``Z,P``M<0"(`RZ$"``P@9AA("@8`$$0``P]`"@&+@0(`00:``.,0``M=(`
M8`Q``%[>D!``&X"B(``20``GP@9AA+H'8`'"!F&$A`=@`8"@0`($0``AN`<@
M!$``7LV0$"``0`!>.-`"``"2$``:E!``'4``7GR6$"``H)(@``)``!7&!B&`
MP@0``,0`8`B`B*0`$D__YO8`P!Q``%Z]D!`@`$``7BC0`@``T@0``)00(`!`
M`%[,EA`@`I(0``A``%ZZD!``&X"B(``B3__?N@=@`<(&882$`'__@*"`'0)`
M`&>`H&`!0`!>JI`0(`!``%X5T`(``!,``%24$"`!DA)C*$``7@&6$"`$NI(@
M``)``!(!````0`!>GI`0(`!``%X)T`(``,('8`P5``!4E!*C,$``7?O2`$``
MP@=@#,(`0`#$`&`(`P`0`("(@`$20`!<`0```$``7HZ0$"``0`!=^=`"```3
M``!4E!`@`9(28SA``%WEEA`@!+J2(``B0``1D!`@`!$``%1___CZD!(@X+B2
M(``"0`!3`0```$``7GR0$"``0`!=Y]`"``#"!V`,E!``'$``7=K2`$``D!`@
M`$``7G,W``"U0`!=WM`"``!``%WT`0```,`J``!``%YLD!`@`$``7=?0`@``
M0`!><0$```#`(@``$0``5'__^-V0$B#0@*(@``)``'70)N&(0`!=C9(0(>V"
M&B`1@*```81`(`"`H``(@D`@`("(@`$"0``%EA``"("B/_\20`!B`P``M<0'
MO_S"`>`4A)B``8(0(``20`!:`0```('/X`@!````@*!@``)/_UL!````$&__
M5P$````$1_^;NA`@`3D``+6X%R&$D!`@`$``7D"Z!V`!0`!=J]`"``!``%V7
MDA``&L('``"`H$`=-$__^)`0(``0;_^,`0```$``7C20$"``0`!=G]`"``#"
M!V`,0`!=]M(`0``0;_^?`0```$``7BLW/__[T`(``$``796V%N/X`P``M<0'
M8`RV!X`;P@!A@!$``%22$``;D!(C0)00+__T`(``0`!=]O(`0`"XDB``!$``
M'8('/__$3L`!@*"@`!)(``8W/__[@*!@``)``!:X$``!-S__^Y(0("^V%N/X
ME!``'+8'@!M``%WWD!``&X"B(``"0``,`0```$``7@>0$"``0`!=<M`"``"2
M$``:E!``&T``7;"6$``<$&__C)`0(`!``%W]D!`@`$``76C0`@``DA``&D``
M75R4$``9$&__@Y`0(`!``%V^`0```!$``%34!N&(P@!A@)`2(X!``%W-T@!`
M`#D``+5___Q\T`<A@,('8`S0)N&(P@!``,0`8`B`B*0``D``$P$```#0`&`,
M0`!=A-('(8#"!V`,Q`<A@,(`0`#X`(``Q`!@"("(I``"0``3MA``"-0`8`P1
M``!4DA``')`2(U!``%VREA``&T``7=&0$"``0`!=/-`"``#"!V`,E!`@`)80
M(`)``%W?T@!``!!O_^<!````0`!=QI`0(`!``%TQT`(``,('8`R4$"``EA`@
M`D``7=32`$``$&__YY00``@P:``$`0````$````!````G>._H'__^O>0$``8
MQ`H``(4HH!B`H*```D``#+H0``B"`B`!A3B@&("@H"^[9$`!@@!@`<0(?_^%
M**`8@*"@`!)/__J%.*`8?__[O@$```"`HB```D``$`$```"`IB```D``#0$`
M``#"3@``@*!@``)```D!````$P``5)`0`!U``%U8DA)BR("G0`@"0``$`0``
M`('/X`@!````$&_XL8'H```P:``'`0````$````!`````0````$````!````
MG>._H)`0(`!``%V%,P``2]`"``"T$"``0`!<[K(68V!``%S[DA`__T``77V0
M$"``0`!<Z-`"```0@%V+D>@`")WCOZ`#``!<+P``7'__\B.N!>(@@AA_,((%
MP`'V`$``@*!@`+=D8``0@%R_@>@``#!H``0!`````0````$```"=X[^@-P``
M`#D````O``!<?__R$JX%X=RV'O[4?__Q2[@?/M2V!<`;N`7`'+8FP!R#/N`?
M@8!@`+;^X`0"0``+NA`@`,('``"0$``8DA``&900`!J?P$``N@=@`8"G0!L2
M3__YN`<@!('/X`@!````,&@`!`$````!`````0```('#X`@!````,&@`!@$`
M```!`````0````$````!````G>._H#L``+"Z%V`$P@=__("@?_\"0``(N@=_
M_)_`0``!````P@=__("@?_\23__\N@=__('/X`@!`````0```)WCOZ"!S^`(
M`0```#!H``4!`````0````$````!````G>._H'__\=<!````@<?@"('H````
M``````(``0`````E<R\E<P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@``````<&5R;'AS:2YC`````````$EN=&5R;F%L<SHZ4$%2.CI"3T]4````
M`"]P<F]C+R5I+R5S``````!E>&4``````"X`````````4$%27U1%35``````
M`````%!!4E]04D]'3D%-10`````Z`````````"5S)7,E<P``+P````````!0
M15),-4Q)0@``````````4$523$Q)0@!015),-4]05```````````4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!3@``
M``````!005)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]!4D=#
M``````````!005)?05)'5E\P````````4$%27T=,3T)!3%]$14)51P``````
M````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%
M04X]````````,0````````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)2
M05)97U!!5$@`````1%E,1%],24)205)97U!!5$@`````````55-%4@````!3
M65-414T``$,Z7%1%35``+W1M<`````!435!$25(``%1%35!$25(`5$5-4```
M``!435```````%5315).04U%```````````E<R5S)7,E<P``````````<&%R
M+0````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"4P,G@`````
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````$%21U8`
M````&`````````!P97)L`````#``````````+W!R;V,O<V5L9B]E>&4``"5S
M.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*````)7,````````M
M90```````"TM````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("``````````````````````0<____^````C(2]U<W(O8FEN+W!E<FP*979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@
M7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY
M(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC
M;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I
M;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q
M=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E
M('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R
M(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@
M(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A
M<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E
M;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E
M9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R
M92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@
M<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U
M<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI
M;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL
M"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*
M("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@
M(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@
M4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@
M("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP
M)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R
M96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@
M(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@
M('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*
M7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!]
M(&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.
M5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*
M("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H
M:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%2
M7T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E
M0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-
M86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M
M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F
M:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O
M<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H
M7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@
M<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<
M;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@
M)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T
M:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E
M7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68[
M"B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN
M+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I
M;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@
M>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL
M92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@
M("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN
M="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@
M("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E
M9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD
M(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE
M;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@
M("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@
M(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@
M("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T
M("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@
M("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE
M(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@
M("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO
M8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I
M(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@
M("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@
M("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@
M("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN
M960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@
M("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@
M("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F
M:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D
M;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R
M8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@
M8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I
M;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA
M;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O
M;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*
M("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL
M97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S
M<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(
M96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D
M=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C
M(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U
M:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@
M("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@
M("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53
M=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@
M(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]
M?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@
M("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U
M;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!
M4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U
M<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"
M54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E
M>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T
M;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI
M;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V
M97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D
M(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!0
M4D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N
M('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C
M(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@
M96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@
M("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@('T*
M("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M
M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@("`@
M("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@
M("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@
M("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@
M("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@
M("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I970@
M/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@
M("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@
M("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@
M("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@
M("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]
M"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*
M"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*
M("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I
M;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF
M("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@
M8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*
M("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@
M("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@
M("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I
M;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D
M<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@
M("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@
M("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O
M<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE
M9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?
M1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y
M?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]
M?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G
M:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@
M?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@
M("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@
M:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@
M("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@
M(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@
M("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@
M/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A
M+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L
M92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@
M("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W
M.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\
M+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@
M("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G
M<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@
M9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H
M87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@
M("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A
M;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[
M)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E
M;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@
M("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE
M(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@
M("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH
M7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@
M("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E
M;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U
M=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R
M968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@
M("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@
M)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@
M("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@
M1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A
M(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E
M($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@
M("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE
M="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@
M("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE
M<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@(&EF(&QC
M*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*
M"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG
M<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@
M("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ
M4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K
M87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@
M("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z
M.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*
M("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<
M,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@
M("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D
M9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@
M("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!
M4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO
M860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE
M('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D
M+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@
M(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z
M.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@
M("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF
M("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@
M("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H
M6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@
M("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S
M(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@
M("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]
M($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I
M;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U
M:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@
M:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N
M:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@
M(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R
M.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*
M("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97([
M"B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*
M("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:
M;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!
M4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$
M:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R
M97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*
M("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H
M.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@
M<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@
M;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H
M:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P
M87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX[
M"B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*
M("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@
M(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R
M93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@
M("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@
M("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E
M<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@
M(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*
M("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@
M("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@
M<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*
M("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@
M("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@
M("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z
M.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R
M;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F
M:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@
M("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S
M=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F
M:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@
M)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D
M97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL
M:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`
M=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@
M<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*
M("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A
M.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE
M*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE
M.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]
M"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@
M("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I
M9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#
M;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@
M("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@
M("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N
M86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!0
M5T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@
M("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@
M("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?
M:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W
M*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'
M0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@
M("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@
M("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF
M("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU
M92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*
M("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@
M("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@
M("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@
M(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@
M('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S
M8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI
M"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*
M(VQI;F4@,3`Q,@H*7U]%3D1?7PH`````````<&%R+G!L```!&P,[````X```
M`!O__V3(```#&/__:(@```#X__]]J````1#__WZH```!*/__?L@```%`__]_
M2````5C__X%(```!</__@J@```&(__^#:````:#__X7(```!N/__A@@```'0
M__^&:````>C__X=(```"`/__AV@```(4__^)B````BS__XG(```"0/__BT@`
M``)8__^-*````G#__XV(```"B/__C<@```*@__^/"````KC__YBH```"T/__
MG>@```+H__^>J````P#__Y[H```#,/__GR@```-(__^?J````V`````0````
M``%Z4@`$?`\!&PP.`````!0````8__]GB```%0@`00T>+0D/'P```!0````P
M__]\D````/0`00T>+0D/'P```!0```!(__]]>````!@`00T>+0D/'P```!0`
M``!@__]]@````'``00T>+0D/'P```!0```!X__]]Z````?0`00T>+0D/'P``
M`!0```"0__]_T````5P`00T>+0D/'P```!0```"H__^!&````+P`00T>+0D/
M'P```!0```#`__^!P````D@`00T>+0D/'P```!0```#8__^$"````#0`00T>
M+0D/'P```!0```#P__^$,````%``00T>+0D/'P```!0```$(__^$>````-``
M0PT>+0D/'P```!````$@__^%0`````P`````````%````33__X5,```"$`!!
M#1XM"0\?````$````4S__X=4````0``````````4```!8/__AX````%T`$$-
M'BT)#Q\````4```!>/__B.@```'0`$$-'BT)#Q\````4```!D/__BK````!8
M`$$-'BT)#Q\````4```!J/__BO@````H`$$-'BT)#Q\````4```!P/__BR``
M``$P`$$-'BT)#Q\````4```!V/__C$@```F(`$,-'BT)#Q\````4```!\/__
ME=````4P`$$-'BT)#Q\````4```""/__FO@```"D`$$-'BT)#Q\````4```"
M(/__FZ````!``$$-'BT)#Q\````4```"./__8:@```)L`$$-'BT)#Q\````4
M```"4/__F[`````P`$$-'BT)#Q\````4```":/__F]@```!P`$$-'BT)#Q\`
M```0```"@/__G$`````(````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_____P````#_____```````````````!`````0````$`
M``*Y`````0```L@````!```"U`````$```+?`````0```ND````!```"]P``
M``$```,$`````0```U,````/```$R0```!T```3)````#``!%(@````-``%0
M0&___O4``0&,````!0`!"B`````&``$$4`````H```4=````"P```!`````5
M``````````,``L%``````@```\P````4````!P```!<``1"\````!P`!$)@`
M```(```#\`````D````,;____@`!#_AO____`````F____```0\^````````
M``````````````````````````````````````````````````````````+`
M%```````````````````````````````````````````````````````````
M```````````````````````````#```P,+__\P$````#```\,+__\`$````#
M``!(,+__[0$````#``!4,+__Z@$````#``!@,+__YP$````#``!L,+__Y`$`
M```#``!X,+__X0$````#``"$,+__W@$````#``"0,+__VP$````#``"<,+__
MV`$````#``"H,+__U0$````#``"T,+__T@$````#``#`,+__SP$````#``#,
M,+__S`$````#``#8,+__R0$````#``#D,+__Q@$````#``#P,+__PP$````#
M``#\,+__P`$````#``$(,+__O0$````#``$4,+__N@$````#``$@,+__MP$`
M```#``$L,+__M`$````#``$X,+__L0$````#``%$,+__K@$````#``%0,+__
MJP$````#``%<,+__J`$````#``%H,+__I0$````#``%T,+__H@$````#``&`
M,+__GP$````#``&,,+__G`$````#``&8,+__F0$````#``&D,+__E@$````#
M``&P,+__DP$````#``&\,+__D`$````#``'(,+__C0$````#``'4,+__B@$`
M```#``'@,+__AP$````#``'L,+__A`$````#``'X,+__@0$````#``($,+__
M?@$````#``(0,+__>P$````#``(<,+__>`$````#``(H,+__=0$````#``(T
M,+__<@$````#``)`,+__;P$````#``),,+__;`$````#``)8,+__:0$````#
M``)D,+__9@$````#``)P,+__8P$````#``)\,+__8`$````#``*(,+__70$`
M```#``*4,+__6@$````#``*@,+__5P$````#``*L,+__5`$````#``*X,+__
M40$````#``+$,+__3@$````#``+0,+__2P$````#``+<,+__2`$````#``+H
M,+__10$````#``+T,+__0@$````#``,`,+__/P$````#``,,,+__/`$````#
M``,8,+__.0$````#``,D,+__-@$````#``,P,+__,P$````#``,\,+__,`$`
M```#``-(,+__+0$````#``-4,+__*@$````#``-@,+__)P$````#``-L,+__
M)`$````#``-X,+__(0$````#``.$,+__'@$````#``.0,+__&P$````#``.<
M,+__&`$````#``.H,+__%0$````#``.T,+__$@$````#``/`,+__#P$````#
M``/,,+__#`$````#``/8,+__"0$````#``/D,+__!@$````#``/P,+__`P$`
M```!`````````/____\``%OI``&P$$=#0SH@*$=.52D@-"XV+C`@,C`Q,3`R
M,3(@*%)E9"!(870@-"XV+C`M,"XW*0``+G-H<W1R=&%B`"YI;G1E<G``+FYO
M=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N
M9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F
M<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M```````````````````````````````````+`````0````(``0$T```!-```
M`!,```````````````$`````````$P````<````"``$!2````4@````@````
M```````````$`````````"$````'`````@`!`6@```%H````)```````````
M````!``````````T;___]@````(``0&,```!C````L0````%``````````0`
M```$````/@````L````"``$$4```!%````70````!@````$````$````$```
M`$8````#`````@`!"B````H@```%'0```````````````0````````!.;___
M_P````(``0\^```//@```+H````%``````````(````"````6V____X````"
M``$/^```#_@```"@````!@````(````$`````````&H````$`````@`!$)@`
M`!"8````)`````4`````````!`````P```!T````!`````(``1"\```0O```
M`\P````%````%@````0````,````?@````$````&``$4B```%(@```!(````
M```````````$`````````(0````!````!@`!%.```!3@```[8```````````
M````(`````````"*`````0````8``5!```!00````!0```````````````0`
M````````D`````$````"``%06```4%@``%_````````````````(````````
M`)@````!`````@`!L!@``+`8````Y```````````````!`````````"F````
M`0````(``;#\``"P_````I0```````````````0`````````L`````$````#
M``+`````P``````(```````````````$`````````+<````!`````P`"P`@`
M`,`(````"```````````````!`````````"^`````0````,``L`0``#`$```
M``0```````````````0`````````PP````8````#``+`%```P!0```$8````
M!@`````````$````"````,P````!`````P`"P2P``,$L````%```````````
M````!`````0```!Y`````0````<``L%```#!0```!`````````````````0`
M````````T0````$````#``+%0```Q4`````0```````````````$````````
M`-<````(`````P`"Q5```,50```00```````````````"`````````#<````
M`0```#````````#%4````"X```````````````$````!`````0````,`````
<````````Q7X```#E```````````````!````````
